==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/CreateFunnelDrillDownSegmentSnapshotMutationRequest.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperation;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperationRequest;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;

@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:58+0800"
)
public class CreateFunnelDrillDownSegmentSnapshotMutationRequest implements GraphQLOperationRequest {

    private static final GraphQLOperation OPERATION_TYPE = GraphQLOperation.MUTATION;
    private static final String OPERATION_NAME = "createFunnelDrillDownSegmentSnapshot";

    private Map<String, Object> input = new LinkedHashMap<>();

    public CreateFunnelDrillDownSegmentSnapshotMutationRequest() {
    }

    public void setProjectId(String projectId) {
        this.input.put("projectId", projectId);
    }

    public void setFunnelDrillDownSegment(FunnelDrillDownSegmentInputDto funnelDrillDownSegment) {
        this.input.put("funnelDrillDownSegment", funnelDrillDownSegment);
    }

    @Override
    public GraphQLOperation getOperationType() {
        return OPERATION_TYPE;
    }

    @Override
    public String getOperationName() {
        return OPERATION_NAME;
    }

    @Override
    public Map<String, Object> getInput() {
        return input;
    }

    @Override
    public String toString() {
        return Objects.toString(input);
    }

    public static class Builder {

        private String projectId;
        private FunnelDrillDownSegmentInputDto funnelDrillDownSegment;

        public Builder() {
        }

        public Builder setProjectId(String projectId) {
            this.projectId = projectId;
            return this;
        }

        public Builder setFunnelDrillDownSegment(FunnelDrillDownSegmentInputDto funnelDrillDownSegment) {
            this.funnelDrillDownSegment = funnelDrillDownSegment;
            return this;
        }


        public CreateFunnelDrillDownSegmentSnapshotMutationRequest build() {
            CreateFunnelDrillDownSegmentSnapshotMutationRequest obj = new CreateFunnelDrillDownSegmentSnapshotMutationRequest();
            obj.setProjectId(projectId);
            obj.setFunnelDrillDownSegment(funnelDrillDownSegment);
            return obj;
        }

    }
}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/CreateFunnelDrillDownSegmentSnapshotMutationRequest.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperation;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLOperationRequest;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;

@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class CreateFunnelDrillDownSegmentSnapshotMutationRequest implements GraphQLOperationRequest {

    private static final GraphQLOperation OPERATION_TYPE = GraphQLOperation.MUTATION;
    private static final String OPERATION_NAME = "createFunnelDrillDownSegmentSnapshot";

    private Map<String, Object> input = new LinkedHashMap<>();

    public CreateFunnelDrillDownSegmentSnapshotMutationRequest() {
    }

    public void setProjectId(String projectId) {
        this.input.put("projectId", projectId);
    }

    public void setFunnelDrillDownSegment(FunnelDrillDownSegmentInputDto funnelDrillDownSegment) {
        this.input.put("funnelDrillDownSegment", funnelDrillDownSegment);
    }

    @Override
    public GraphQLOperation getOperationType() {
        return OPERATION_TYPE;
    }

    @Override
    public String getOperationName() {
        return OPERATION_NAME;
    }

    @Override
    public Map<String, Object> getInput() {
        return input;
    }

    @Override
    public String toString() {
        return Objects.toString(input);
    }

    public static class Builder {

        private String projectId;
        private FunnelDrillDownSegmentInputDto funnelDrillDownSegment;

        public Builder() {
        }

        public Builder setProjectId(String projectId) {
            this.projectId = projectId;
            return this;
        }

        public Builder setFunnelDrillDownSegment(FunnelDrillDownSegmentInputDto funnelDrillDownSegment) {
            this.funnelDrillDownSegment = funnelDrillDownSegment;
            return this;
        }


        public CreateFunnelDrillDownSegmentSnapshotMutationRequest build() {
            CreateFunnelDrillDownSegmentSnapshotMutationRequest obj = new CreateFunnelDrillDownSegmentSnapshotMutationRequest();
            obj.setProjectId(projectId);
            obj.setFunnelDrillDownSegment(funnelDrillDownSegment);
            return obj;
        }

    }
}
